==> smile-0.3.2.tar.gz: smile/thtra.cpp <==
#include "thtra.h"
 
thtra::thtra()
{
	srcImage3 = srcImage3.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor );
	//srcImage3 = srcImage3.scaled ( 720, 576, Qt::IgnoreAspectRatio, Qt::FastTransformation );
}

void thtra::run()
{

	QImage srcImage(wl_width,wl_height,QImage::Format_ARGB32);
	QImage srcImage2(wl_width,wl_height,QImage::Format_ARGB32);
	QImage dstImage(wl_width,wl_height,QImage::Format_ARGB32);

	increment_sequence = (float)(100 / duree);
	sequence = 0;

	k = (uint)(o);

	if ( numtrans == 1 )
	{
		// *** Fondu enchaine ***
		while (sequence < 100)
		{
			wl_var_1 = "000000000";
			wl_var_2 = QString::number(k);
			wl_var_1.replace( 9 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
			wendfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			//
			if ( rendering_number > 0 )
			{
				n = (uint)(k - duree);
				wl_var_1 = "000000000";
				wl_var_2 = QString::number(n);
				wl_var_1.replace( 9 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
				wstartfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			}
			else
			{
				wstartfile = wpathprojet + "/SMILE_fdnoir.jpg";
			}
			if (srcImage.load(wstartfile) == false)
			{
				qDebug() << "ERROR LOADING SRC1 = " << wstartfile;
			}
			if (srcImage2.load(wendfile) == false)
			{
				qDebug() << "ERROR LOADING SRC2 = " << wendfile;
			}
			for (int y = 0; y < srcImage.height(); y++)
			{
				for (int x = 0; x < srcImage.width(); x++) //srcImage.width()
				{
					QRgb srcPixel = srcImage.pixel(x, y);
					QRgb srcPixel2 = srcImage2.pixel(x, y);
					tmpcolor1 = srcPixel;
					tmpcolor2 = srcPixel2;
					tmpcolor3.setRed(tmpcolor1.red() * (1-(float)((float)sequence/(float)100)) + tmpcolor2.red() * (float)((float)sequence/(float)100));
					tmpcolor3.setGreen(tmpcolor1.green() * (1-(float)((float)sequence/(float)100)) + tmpcolor2.green() * (float)((float)sequence/(float)100));
					tmpcolor3.setBlue(tmpcolor1.blue() * (1-(float)((float)sequence/(float)100)) + tmpcolor2.blue() * (float)((float)sequence/(float)100));
					QRgb dstPixel(tmpcolor3.rgb());
					dstImage.setPixel(x, y, dstPixel);
				}				
			}
			sequence=sequence + increment_sequence;
			if ( rendering_number > 0 )
			{
				if ( dstImage.save(wstartfile,"JPG") == false )
				{
					qDebug() << "ERROR SAVING RENDER FILE : " << wstartfile;
				}
				if ( QFile::remove ( wendfile ) == false )
				{
					qDebug() << "ERROR REMOVING FILE FROM RENDERING DIRECTORY : " << wendfile;
				}
			}
			else
			{
				if ( dstImage.save(wendfile,"JPG") == false )
				{
					qDebug() << "ERROR RENDERING SAVING FILE : " << wstartfile;
				}
			}
			k = k + 1;
			emit nextstep();
		}
	}
	else
	{
		// *** Transitions par luma ***
		progress = 0;
		mycolor.setRed((float)((float)255/(float)100)*(float)progress);
		mycolor.setGreen((float)((float)255/(float)100)*(float)progress);
		mycolor.setBlue((float)((float)255/(float)100)*(float)progress);
		while (sequence < 100)
		{
			wl_var_1 = "000000000";
			wl_var_2 = QString::number(k);
			wl_var_1.replace( 9 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
			wendfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			//
			if ( rendering_number > 0 )
			{
				n = (uint)(k - duree);
				wl_var_1 = "000000000";
				wl_var_2 = QString::number(n);
				wl_var_1.replace( 9 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
				wstartfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			}
			else
			{
				wstartfile = wpathprojet + "/SMILE_fdnoir.jpg";
			}
			if (srcImage.load(wstartfile) == false)
			{
				qDebug() << "ERROR LOADING SRC1 = " << wstartfile;
			}
			if (srcImage2.load(wendfile) == false)
			{
				qDebug() << "ERROR LOADING SRC2 = " << wendfile;
			}

			for (int y = 0; y < srcImage.height(); y++)
			{
				for (int x = 0; x < srcImage.width(); x++) //srcImage.width()
				{
					QRgb srcPixel = srcImage.pixel(x, y);
					QRgb srcPixel2 = srcImage2.pixel(x, y);
					QRgb srcPixel3 = srcImage3.pixel(x, y);
					tmpcolor1 = srcPixel;
					tmpcolor2 = srcPixel2;
					tmpcolor3 = srcPixel3;
					if ( tmpcolor3.value() > mycolor.value() )
					{
						dstImage.setPixel(x, y, srcPixel);
					}
					else
					{
						dstImage.setPixel(x, y, srcPixel2);
					}
				}
			}
			progress = progress + increment_sequence;
			mycolor.setRed((float)((float)255/(float)100)*(float)progress);
			mycolor.setGreen((float)((float)255/(float)100)*(float)progress);
			mycolor.setBlue((float)((float)255/(float)100)*(float)progress);
			sequence=sequence + increment_sequence;
			if ( rendering_number > 0 )
			{
				if ( dstImage.save(wstartfile,"JPG") == false )
				{
					qDebug() << "ERROR SAVING RENDER FILE : " << wstartfile;
				}
				if ( QFile::remove ( wendfile ) == false )
				{
					qDebug() << "ERROR REMOVING FILE FROM RENDERING DIRECTORY : " << wendfile;
				}
			}
			else
			{
				if ( dstImage.save(wendfile,"JPG") == false )
				{
					qDebug() << "ERROR RENDERING SAVING FILE : " << wstartfile;
				}
			}
			k = k + 1;
			emit nextstep();
		}
	}
	emit myfin();
	exec();
}

==> smile-0.6.7.tar.gz: smile/thtra.cpp <==
#include "thtra.h"
 
thtra::thtra()
{
	srcImage3 = srcImage3.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor );
	//srcImage3 = srcImage3.scaled ( 720, 576, Qt::IgnoreAspectRatio, Qt::FastTransformation );
}

void thtra::run()
{

	QImage srcImage(wl_width,wl_height,QImage::Format_ARGB32);
	QImage srcImage2(wl_width,wl_height,QImage::Format_ARGB32);
	QImage dstImage(wl_width,wl_height,QImage::Format_ARGB32);

	increment_sequence = (float)(100 / duree);
	sequence = 0;

	k = (ulong)(o);

	if ( numtrans == 1 )
	{
		// *** Fondu enchaine ***
		while (sequence < 100)
		{
			wl_var_1 = "0000000000";
			wl_var_2 = QString::number(k);
			wl_var_1.replace( 10 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
			wendfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			//
			if ( rendering_number > 0 )
			{
				n = (uint)(k - duree);
				wl_var_1 = "0000000000";
				wl_var_2 = QString::number(n);
				wl_var_1.replace( 10 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
				wstartfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			}
			else
			{
				wstartfile = wpathprojet + "/SMILE_fdnoir.jpg";
			}
			//qDebug() << "SRC1 = " << wstartfile;
			//qDebug() << "SRC2 = " << wendfile;
			if (srcImage.load(wstartfile) == false)
			{
				qDebug() << "ERROR LOADING SRC1 = " << wstartfile;
			}
			if (srcImage2.load(wendfile) == false)
			{
				qDebug() << "ERROR LOADING SRC2 = " << wendfile;
			}
			for (int y = 0; y < srcImage.height(); y++)
			{
				for (int x = 0; x < srcImage.width(); x++)
				{
					QRgb srcPixel = srcImage.pixel(x, y);
					QRgb srcPixel2 = srcImage2.pixel(x, y);
					tmpcolor1 = srcPixel;
					tmpcolor2 = srcPixel2;
					tmpcolor3.setRed(tmpcolor1.red() * (1-(float)((float)sequence/(float)100)) + tmpcolor2.red() * (float)((float)sequence/(float)100));
					tmpcolor3.setGreen(tmpcolor1.green() * (1-(float)((float)sequence/(float)100)) + tmpcolor2.green() * (float)((float)sequence/(float)100));
					tmpcolor3.setBlue(tmpcolor1.blue() * (1-(float)((float)sequence/(float)100)) + tmpcolor2.blue() * (float)((float)sequence/(float)100));
					QRgb dstPixel(tmpcolor3.rgb());
					dstImage.setPixel(x, y, dstPixel);
				}				
			}
			sequence=sequence + increment_sequence;
			if ( rendering_number > 0 )
			{
				if ( dstImage.save(wstartfile,"JPG") == false )
				{
					qDebug() << "ERROR SAVING RENDER FILE : " << wstartfile;
				}
				if ( QFile::remove ( wendfile ) == false )
				{
					qDebug() << "ERROR REMOVING FILE FROM RENDERING DIRECTORY : " << wendfile;
				}
			}
			else
			{
				if ( dstImage.save(wendfile,"JPG") == false )
				{
					qDebug() << "ERROR RENDERING SAVING FILE : " << wstartfile;
				}
			}
			k = k + 1;
			emit nextstep();
		}
	}
	else
	{
		// *** Transitions par luma ***
		if ( invert == "0" )
		{
			progress = 0;
		}
		else
		{
			progress = 100;
		}
		mycolor.setRed((float)((float)255/(float)100)*(float)progress);
		mycolor.setGreen((float)((float)255/(float)100)*(float)progress);
		mycolor.setBlue((float)((float)255/(float)100)*(float)progress);
		while (sequence < 100)
		{
			wl_var_1 = "0000000000";
			wl_var_2 = QString::number(k);
			wl_var_1.replace( 10 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
			wendfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			//
			if ( rendering_number > 0 )
			{
				n = (uint)(k - duree);
				wl_var_1 = "0000000000";
				wl_var_2 = QString::number(n);
				wl_var_1.replace( 10 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
				wstartfile = wpathprojet + "/Slide_xxx_" + wl_var_1 + ".jpg";
			}
			else
			{
				wstartfile = wpathprojet + "/SMILE_fdnoir.jpg";
			}
			if (srcImage.load(wstartfile) == false)
			{
				qDebug() << "ERROR LOADING SRC1 = " << wstartfile;
			}
			if (srcImage2.load(wendfile) == false)
			{
				qDebug() << "ERROR LOADING SRC2 = " << wendfile;
			}

			for (int y = 0; y < srcImage.height(); y++)
			{
				for (int x = 0; x < srcImage.width(); x++)
				{
					QRgb srcPixel = srcImage.pixel(x, y);
					QRgb srcPixel2 = srcImage2.pixel(x, y);
					QRgb srcPixel3 = srcImage3.pixel(x, y);
					tmpcolor1 = srcPixel;
					tmpcolor2 = srcPixel2;
					tmpcolor3 = srcPixel3;
					if ( invert == "0" )
					{
						if ( tmpcolor3.value() > mycolor.value() )
						{
							dstImage.setPixel(x, y, srcPixel);
						}
						else
						{
							dstImage.setPixel(x, y, srcPixel2);
						}
					}
					else
					{
						if ( tmpcolor3.value() > mycolor.value() )
						{
							dstImage.setPixel(x, y, srcPixel2);
						}
						else
						{
							dstImage.setPixel(x, y, srcPixel);
						}
					}
				}
			}
			if ( invert == "0" )
			{
				progress = progress + increment_sequence;
			}
			else
			{
				progress = progress - increment_sequence;
			}
			mycolor.setRed((float)((float)255/(float)100)*(float)progress);
			mycolor.setGreen((float)((float)255/(float)100)*(float)progress);
			mycolor.setBlue((float)((float)255/(float)100)*(float)progress);
			sequence=sequence + increment_sequence;
			if ( rendering_number > 0 )
			{
				if ( dstImage.save(wstartfile,"JPG") == false )
				{
					qDebug() << "ERROR SAVING RENDER FILE : " << wstartfile;
				}
				if ( QFile::remove ( wendfile ) == false )
				{
					qDebug() << "ERROR REMOVING FILE FROM RENDERING DIRECTORY : " << wendfile;
				}
			}
			else
			{
				if ( dstImage.save(wendfile,"JPG") == false )
				{
					qDebug() << "ERROR RENDERING SAVING FILE : " << wstartfile;
				}
			}
			k = k + 1;
			emit nextstep();
		}
	}
	emit myfin();
	exec();
}
